@@ -515,8 +515,7 @@ namespace Breeze
     //______________________________________________________________________________
     void Helper::renderFrame(
         QPainter* painter, const QRect& rect,
-        const QColor& color, const QColor& outline,
-        FrameHints hints ) const
+        const QColor& color, const QColor& outline ) const
     {
 
         painter->setRenderHint( QPainter::Antialiasing );
@@ -542,19 +541,6 @@ namespace Breeze
         if( color.isValid() ) painter->setBrush( color );
         else painter->setBrush( Qt::NoBrush );
 
-        if (hints & FrameHint::DoubleRing) {
-            painter->save();
-            {
-                auto rect2 = frameRect.adjusted( -2, -2, 2, 2 );
-                painter->setPen( Qt::NoPen );
-                painter->setBrush( outline );
-                painter->setOpacity( 0.4 );
-
-                painter->drawRoundedRect(rect2, radius*2, radius*2);
-            }
-            painter->restore();
-        }
-
         // render
         painter->drawRoundedRect( frameRect, radius, radius );
 
